# ![brilleu]
An interface between [brille] and [Euphonic]

[brilleu]: https://raw.githubusercontent.com/g5t/brilleu/master/brilleu.svg
[brille]: https://pypi.org/project/brille/
[Euphonic]: https://pypi.org/project/euphonic/